@@ -1,7 +1,7 @@
 package Perinci::Examples::Stream;
 
 our $DATE = '2015-01-20'; # DATE
-our $VERSION = '0.48'; # VERSION
+our $VERSION = '0.49'; # VERSION
 
 use 5.010;
 use strict;
@@ -22,29 +22,50 @@ _
 $SPEC{nat} = {
     v => 1.1,
     summary => 'This function produces a stream of natural numbers',
-    args => {},
+    args => {
+        num => {
+            schema => 'int*',
+            cmdline_aliases => {n=>{}},
+        },
+    },
     result => {
         stream => 1,
         schema => 'int*',
     },
 };
 sub nat {
+    my %args = @_;
     my $i = 1;
-    [200, "OK", sub { $i++ }];
+    my $num = $args{num};
+    [200, "OK", sub {
+         return undef if defined($num) && $i > $num;
+         $i++;
+     }];
 }
 
 $SPEC{hash_stream} = {
     v => 1.1,
     summary => 'This function produces a stream of hashes',
-    args => {},
+    args => {
+        num => {
+            schema => 'int*',
+            cmdline_aliases => {n=>{}},
+        },
+    },
     result => {
         stream => 1,
         schema => 'hash*',
     },
 };
 sub hash_stream {
+    my %args = @_;
+    my $num = $args{num};
+
     my $i = 1;
-    [200, "OK", sub { {num=>$i++} }];
+    [200, "OK", sub {
+         return undef if defined($num) && $i > $num;
+         {num=>$i++};
+     }];
 }
 
 $SPEC{square_input} = {
@@ -149,7 +170,7 @@ Perinci::Examples::Stream - Examples for streaming input/output
 
 =head1 VERSION
 
-This document describes version 0.48 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2015-01-20.
+This document describes version 0.49 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2015-01-20.
 
 =head1 DESCRIPTION
 
@@ -161,11 +182,17 @@ This package contains functions that demonstrate streaming input/output.
 =head1 FUNCTIONS
 
 
-=head2 hash_stream() -> [status, msg, result, meta]
+=head2 hash_stream(%args) -> [status, msg, result, meta]
 
 {en_US This function produces a stream of hashes}.
 
-No arguments.
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<num> => I<int>
+
+=back
 
 Returns an enveloped result (an array).
 
@@ -179,11 +206,17 @@ that contains extra information.
 Return value:  (hash)
 
 
-=head2 nat() -> [status, msg, result, meta]
+=head2 nat(%args) -> [status, msg, result, meta]
 
 {en_US This function produces a stream of natural numbers}.
 
-No arguments.
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<num> => I<int>
+
+=back
 
 Returns an enveloped result (an array).
 
